@@ -16,7 +16,7 @@ from functools import wraps
 import click
 import numpy
 
-from jaeger import log
+from jaeger import config, log
 from jaeger.commands.bootloader import load_firmware
 from jaeger.commands.calibration import calibrate_positioner
 from jaeger.fps import FPS
@@ -102,6 +102,9 @@ pass_fps = click.make_pass_decorator(FPSWrapper, ensure=True)
 
 
 @click.group(invoke_without_command=True)
+@click.option('-c', '--config', 'config_file',
+              type=click.Path(exists=True, dir_okay=False),
+              help='Path to the user configuration file.')
 @click.option('-p', '--profile', type=str, help='The bus interface profile.')
 @click.option('-l', '--layout', type=str, help='The FPS layout.')
 @click.option('-v', '--verbose', is_flag=True, help='Debug mode.')
@@ -112,13 +115,17 @@ pass_fps = click.make_pass_decorator(FPSWrapper, ensure=True)
               help='Enables engineering mode. Most safety checks will be disabled.')
 @click.pass_context
 @cli_coro
-async def jaeger(ctx, layout, profile, verbose, no_tron, ieb, qa, danger):
+async def jaeger(ctx, config_file, layout, profile, verbose, no_tron, ieb, qa, danger):
     """CLI for the SDSS-V focal plane system.
 
     If called without subcommand starts the actor.
 
     """
 
+    if config_file:
+        config.load(config_file)
+        config.__CONFIG_FILE__ = str(config_file)
+
     ctx.obj = FPSWrapper(verbose, profile, layout, ieb, qa, danger)
 
     # If we call jaeger without a subcommand and with the actor flag,
@@ -127,10 +134,22 @@ async def jaeger(ctx, layout, profile, verbose, no_tron, ieb, qa, danger):
 
         try:
             from jaeger.actor import JaegerActor
-            from jaeger import config
         except ImportError:
             raise ImportError('CLU needs to be installed to run jaeger as an actor.')
 
+        # TODO: not doing this just yet but may have to enable at some point.
+        # For the actor we require that the configuration is either defined
+        # in $SDSSCORE_DIR or defined as --config.
+        # if config_file is None:
+        #     try:
+        #         obs = os.environ['OBSERVATORY'].lower()
+        #         sdsscore_config = f'$SDSSCORE_DIR/configuration/{obs}/actors/jaeger.yaml'
+        #         config.load(os.path.expandvars(sdsscore_config))
+        #     except (ValueError, KeyError, FileNotFoundError) as ee:
+        #         if ee.__class__ == KeyError:
+        #             ee.args = (f'cannot find environment variable {ee.args[0]}',)
+        #         raise JaegerError(f'Cannot load configuration file from $SDSSCORE_DIR: {ee}')
+
         actor_config = config['actor'].copy()
         actor_config.pop('status', None)
 
